@@ -68,9 +68,15 @@ FAILEDOPERATION_SETRULELOCATIONFAILED = 'FailedOperation.SetRuleLocationFailed'
 # 标签键值校验或鉴权失败。
 FAILEDOPERATION_TAGDRYRUNERROR = 'FailedOperation.TagDryRunError'
 
+# 标签配额不足。
+FAILEDOPERATION_TAGQUOTAEXCEEDLIMIT = 'FailedOperation.TagQuotaExceedLimit'
+
 # 实例安全组信息更新失败。
 FAILEDOPERATION_UPDATEINSTANCEINFOFAILED = 'FailedOperation.UpdateInstanceInfoFailed'
 
+# 用户未实名认证。
+FAILEDOPERATION_USERNOTAUTHED = 'FailedOperation.UserNotAuthed'
+
 # VPC更新路由失败。
 FAILEDOPERATION_VPCUPDATEROUTEFAILED = 'FailedOperation.VpcUpdateRouteFailed'
 
@@ -80,6 +86,9 @@ INTERNALERROR = 'InternalError'
 # CAM鉴权请求失败。
 INTERNALERROR_CAMAUTHFAILED = 'InternalError.CamAuthFailed'
 
+# 校验VIP状态失败。
+INTERNALERROR_CHECKVIPSTATUSFAILED = 'InternalError.CheckVipStatusFailed'
+
 # COS地址配置错误。
 INTERNALERROR_COSCONFIGURATION = 'InternalError.CosConfiguration'
 
@@ -116,6 +125,9 @@ INTERNALERROR_GETRIGHTFAILED = 'InternalError.GetRightFailed'
 # 拉圈安全组详情失败。
 INTERNALERROR_GETSECURITYGROUPDETAILFAILED = 'InternalError.GetSecurityGroupDetailFailed'
 
+# 查询慢日志DB失败。
+INTERNALERROR_GETSLOWLOGFAILED = 'InternalError.GetSlowLogFailed'
+
 # 查询虚拟私有网络子网信息失败。
 INTERNALERROR_GETSUBNETFAILED = 'InternalError.GetSubnetFailed'
 
@@ -176,12 +188,18 @@ INTERNALERROR_SETSVCLOCATIONFAILED = 'InternalError.SetSvcLocationFailed'
 # 数据库更新失败。
 INTERNALERROR_UPDATEDATABASEFAILED = 'InternalError.UpdateDatabaseFailed'
 
+# 外网操作失败。
+INTERNALERROR_WANSERVICEFAILED = 'InternalError.WanServiceFailed'
+
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
 # 密码包含了非法字符。
 INVALIDPARAMETER_CHARACTERERROR = 'InvalidParameter.CharacterError'
 
+# 入参校验失败。
+INVALIDPARAMETER_CHECKPARAMNOTPASS = 'InvalidParameter.CheckParamNotPass'
+
 # 未指定需要查询的订单ID。
 INVALIDPARAMETER_DEALNAMENOTGIVEN = 'InvalidParameter.DealNameNotGiven'
 
@@ -194,6 +212,9 @@ INVALIDPARAMETER_GENERICPARAMETERERROR = 'InvalidParameter.GenericParameterError
 # 非法参数。
 INVALIDPARAMETER_ILLEGALPARAMETERERROR = 'InvalidParameter.IllegalParameterError'
 
+# 错误的时间参数。
+INVALIDPARAMETER_ILLEGALTIME = 'InvalidParameter.IllegalTime'
+
 # 未找到请求的实例。
 INVALIDPARAMETER_INSTANCENOTFOUND = 'InvalidParameter.InstanceNotFound'
 
@@ -218,6 +239,9 @@ INVALIDPARAMETER_SUBNETUNAVAILABLE = 'InvalidParameter.SubnetUnavailable'
 # 找不到指定的虚拟私有网络。
 INVALIDPARAMETER_VPCNOTFOUND = 'InvalidParameter.VpcNotFound'
 
+# 可用区信息错误。
+INVALIDPARAMETER_ZONEIDILLEGAL = 'InvalidParameter.ZoneIdIllegal'
+
 # 想要创建的账号已经存在。
 INVALIDPARAMETERVALUE_ACCOUNTALREADYEXISTS = 'InvalidParameterValue.AccountAlreadyExists'
 
@@ -257,9 +281,15 @@ INVALIDPARAMETERVALUE_SUPERUSERFORBIDDEN = 'InvalidParameterValue.SuperUserForbi
 # 请求过于频繁。
 LIMITEXCEEDED_TOOFREQUENTLYCALLED = 'LimitExceeded.TooFrequentlyCalled'
 
+# 资源不足。
+RESOURCEINSUFFICIENT = 'ResourceInsufficient'
+
 # 指定的账号不存在。
 RESOURCENOTFOUND_ACCOUNTDOESNOTEXIST = 'ResourceNotFound.AccountDoesNotExist'
 
+# 实例不存在。
+RESOURCENOTFOUND_INSTANCENOTFOUND = 'ResourceNotFound.InstanceNotFound'
+
 # 找不到指定的数据库实例。
 RESOURCENOTFOUND_NOINSTANCEFOUND = 'ResourceNotFound.NoInstanceFound'
 
